R_version_in_a_folder: Get the version of the R installed in a folder
Description
Get the version of the R installed in a folder based on
the structure of the filename README.R-... (where ... is
a version number for R). This function helps detect the
version number of an R installation even if the name of
the folder is not standard.
Usage
R_version_in_a_folder(folder)
Arguments
folder
The folder for which we wish to know the R
version.
Value
Returns a character vector of the R version (or NA, if
this is not an R installation folder)