install.FFmpeg: Downloads and installs FFmpeg for windows
Description
Allows the user to downloads the latest version of FFmpeg
for Windows. IMPORTANT NOTE: The user (YOU) are
responsible for unpacking the 7zip file into the relevant
directory. All that this function does is to download
the 7zip file and "run" it.
FFmpeg is a complete, cross-platform solution to record,
convert and stream audio and video. It includes
libavcodec - the leading audio/video codec library. See
the documentation for a complete feature list and the
Changelog for recent changes. This function downloads
current releases and NOT the Development Snapshots. This
function is useful for saveVideo() in the {animation}
package.