TRUE/FALSE - was the installation successful or not.
Details
MiKTeX is a typesetting system for Microsoft Windows that
is developed by Christian Schenk. It consists of an
implementation of TeX and a set of related programs.
MiKTeX provides the tools necessary to prepare documents
using the TeX/LaTeX markup language, as well a simple tex
editor (TeXworks).
MiKTeX is essential for using Sweave, knitr, and creating
Vignette for R packages.