invisible TRUE/FALSE - was the installation successful or
not.
Details
Similar to the windows R gui built in editor, NppToR aims
to extend the functionality of code passing to the
Notepad++ code editor. In addition to passing to the R
gui, NppToR provides optional passing to a PuTTY window
for passing to an R instance a remote machine.
NppToR is a companion utility that facilitates
communication between R and Notepad++. It provides code
passing from Notepad++ into the windows R Gui. NppToR
also provides an autocompletion database which is
dynamically generated from the users' R library of
packages, thanks to an addition by Yihui Xie. Notepad++
provides built it R code highlighting and folding.