Learn R Programming

installr (version 0.17.8)

pkgDNLs_worldmapcolor: Worldmap colored by the number of downloads for a given package

Description

Plots a worldmap colored by the number of users installation for a given package

Usage

pkgDNLs_worldmapcolor(pkg_name, dataset, remove_dups = TRUE, ...)

Arguments

pkg_name
a character string of the package we are interested in.
dataset
a dataset output from running read_RStudio_CRAN_data.
remove_dups
logical (default is TRUE). Should the duplicate user ids (based on their ips) be removed.
...
not in use.

Value

a ggplot object

Details

RStudio maintains its own CRAN mirror, https://cran.rstudio.com/ and offers its log files.

See Also

download_RStudio_CRAN_data, read_RStudio_CRAN_data, barplot_package_users_per_day, ggplot

Examples

Run this code
## Not run: 
# # The first two functions might take a good deal of time to run (depending on the date range)
# RStudio_CRAN_data_folder <- 
#       download_RStudio_CRAN_data(START = '2013-04-02',
#                                  END = '2013-04-05') 
#                                  # around the time R 3.0.0 was released
# my_RStudio_CRAN_data <- read_RStudio_CRAN_data(RStudio_CRAN_data_folder)
# head(my_RStudio_CRAN_data)
# 
# wm <- pkgDNLs_worldmapcolor(pkg_name="installr", dataset = my_RStudio_CRAN_data)
# wm
# 
# ## End(Not run)

Run the code above in your browser using DataLab